# Upstream's primary form of distribution is deb/rpm packages, not sources
# so the have a version-release versioning scheme themselves. Since they
# almost always only do one release per version, we just ignore the -release
# part of the version for our versioning, but we still need to know their
# release in a couple of places
%define upstream_release 1

Name:           blobAndConquer
Version:        0.91
Release:        4%{?dist}
Summary:        Blob Wars 2: Blob And Conquer
Group:          Amusements/Games
License:        GPLv2+
URL:            http://www.parallelrealities.co.uk/blobAndConquer.php
# Non rpm compatible URL: http://www.parallelrealities.co.uk/download.php?file=blobAndConquer-%{version}-%{upstream_release}.tar.gz&type=zip
Source0:        %{name}-%{version}-%{upstream_release}.tar.gz
Patch0:         blobAndConquer-0.90-exit-crash.patch
Patch1:         blobAndConquer-0.90-ppc.patch
BuildRoot:      %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildRequires:  SDL_image-devel SDL_mixer-devel SDL_ttf-devel zlib-devel
BuildRequires:  desktop-file-utils
Requires:       hicolor-icon-theme opengl-games-utils

%description
With the apparent defeat of Galdov and the reclaiming of the Fire, Time, Space
and Reality Crystals the Blobs' battle was only just beginning. Bob had rescued
many Blobs and fought many battles, but now he had an ever bigger task ahead of
him. The Blobs' homeworld is still littered with the alien forces and Bob once
again makes it his task to lead the counter attack. But even without Galdov the
aliens are still extremely well organised...

They're Ready. Will You Be?


%prep
%setup -q
%patch0 -p1 -z .exit
%patch1 -p1 -z .ppc
# some cleanup
chmod -x gfx/rw2/*.raw data/gameDefs/defines.h `find src -type f`
sed -i 's/\r//g' data/gameDefs/defines.h `find src -type f`
sed -i 's/Exec=blobAndConquer/Exec=blobAndConquer-wrapper/' \
  icons/blobAndConquer.desktop


%build
# the long CXXFLAGS isn't pretty, but it really is the easiest way
make CXXFLAGS='%{optflags} `sdl-config --cflags` -DVERSION=%{version} \
  -DRELEASE=%{upstream_release} -DUSEPAK=0 -DDEV=0 -DPAKNAME=\"%{name}.pak\" \
  -DPAKLOCATION=\"%{_datadir}/%{name}\" -DLOCALEDIR=\"%{_datadir}/locale\" \
  -DGAMEPLAYMANUAL=\"%{_docdir}/%{name}-%{version}/index.html\"'


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/48x48/apps
make install DESTDIR=$RPM_BUILD_ROOT BINDIR=$RPM_BUILD_ROOT%{_bindir} \
  DATADIR=$RPM_BUILD_ROOT%{_datadir}/%{name} \
  ICONDIR=$RPM_BUILD_ROOT%{_datadir}/icons/hicolor/48x48/apps
ln -s opengl-game-wrapper.sh $RPM_BUILD_ROOT%{_bindir}/%{name}-wrapper
mkdir installed-docs
mv $RPM_BUILD_ROOT%{_docdir}/%{name}/* installed-docs

desktop-file-install --vendor fedora --delete-original \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  --add-category ActionGame \
  --remove-key Version \
  $RPM_BUILD_ROOT%{_datadir}/applications/%{name}.desktop


%clean
rm -rf $RPM_BUILD_ROOT


%post
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
   %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%postun
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
   %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi


%files
%defattr(-,root,root,-)
%doc installed-docs/*
%{_bindir}/%{name}*
# the data/gameDefs/defines.h file is needed runtime and thus not a devel file!
%{_datadir}/%{name}
%{_datadir}/applications/fedora-%{name}.desktop
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png


%changelog
* Mon Sep 24 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 0.91-4
- Use opengl-games-utils wrapper to show error dialog when DRI is missing

* Tue Aug 21 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 0.91-3
- Rebuild for buildId

* Sun Aug 12 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 0.91-2
- Update License tag for new Licensing Guidelines compliance
- Fix invalid desktop file (fix building with latest desktop-file-utils)

* Sun Jun  3 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 0.91-1
- New upstream release 0.91-1
- Drop upstreamed patches

* Thu May 24 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 0.90-2
- Add missing desktop-file-utils BuildRequire

* Fri May 18 2007 Hans de Goede <j.w.r.degoede@hhs.nl> 0.90-1
- Initial Fedora package
